﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using Infragistics.Win;
using Infragistics.Win.UltraWinDataSource;
using Infragistics.Win.UltraWinGrid;
using Infragistics.Win.FormattedLinkLabel;
using Infragistics.Win.Printing;

namespace GridTest
{
    public partial class Form1 : Form
    {
        private UltraGridPrintDocument _gridPrintDocument;

        public Form1()
        {
            InitializeComponent();

            //System.Data.DataSet dsDataGrid = new DataSet("DataGrid");

            //string filePath = "Sample.xml";
            //dsDataGrid.ReadXml(filePath);

            this.ultraGrid1.DataSource = CreateDataSource();
            this.ultraGrid1.DataBind();

            MakeLeftKeyCollapseRow(ultraGrid1);
            InitializeGridPrintDocument();
        }

        private void MakeLeftKeyCollapseRow(UltraGrid Grid)
        {
            foreach (GridKeyActionMapping ugKam in Grid.KeyActionMappings)
            {
                if (ugKam.KeyCode == Keys.Left)
                {
                    if (ugKam.ActionCode != UltraGridAction.CollapseRow)
                        Grid.KeyActionMappings.Remove(ugKam);
                }
            }
        }

        private UltraDataSource CreateDataSource()
        {
            UltraDataSource ds = CreateNewDataSource();

            // Data binding
            ds.Rows.Clear();

            UltraDataRow drRow;

            drRow = ds.Rows.Add();
            drRow["Name"] = "AAAA";
            drRow["Age"] = "20";

            UltraDataRow childRow = drRow.GetChildRows(0).Add();
            childRow["BookName"] = "Book1";
            childRow["Date"] = DateTime.Today.ToLongDateString();

            childRow = drRow.GetChildRows(0).Add();
            childRow["BookName"] = "Book2";
            childRow["Date"] = DateTime.Today.ToLongDateString();

            drRow = ds.Rows.Add();
            drRow["Name"] = "BBBB";
            drRow["Age"] = "30";

            childRow = drRow.GetChildRows(0).Add();
            childRow["BookName"] = "Book3";
            childRow["Date"] = DateTime.Today.ToLongDateString();

            return ds;
        }

        protected UltraDataSource CreateNewDataSource()
        {
            // 
            UltraDataSource uds = new UltraDataSource();

           UltraDataBand band = uds.Band;

            band.Columns.Add("Name", typeof(string));
            band.Columns.Add("Age", typeof(string));
            
            band = band.ChildBands.Add("Band1");

            band.Columns.Add("BookName", typeof(string));
            band.Columns.Add("Date", typeof(string));

            return uds;
        }
        private void Close_Click(object sender, EventArgs e)
        {
            this.Close();
        }

        void ultraGrid1_GotFocus(object sender, System.EventArgs e)
        {
            
            ultraGrid1.DisplayLayout.Appearance.BorderColor = Color.Red;
        }

        void ultraGrid1_LostFocus(object sender, System.EventArgs e)
        {
            ultraGrid1.DisplayLayout.Appearance.BorderColor = System.Drawing.SystemColors.InactiveCaption;
        }

        private void ultraGrid1_InitializeLayout(object sender, Infragistics.Win.UltraWinGrid.InitializeLayoutEventArgs e)
        {
            
            e.Layout.ScrollBounds = Infragistics.Win.UltraWinGrid.ScrollBounds.ScrollToFill;
            e.Layout.ScrollStyle = Infragistics.Win.UltraWinGrid.ScrollStyle.Immediate;

            e.Layout.ViewStyleBand = Infragistics.Win.UltraWinGrid.ViewStyleBand.Horizontal;
            e.Layout.Override.RowSizing = RowSizing.AutoFree;
            e.Layout.Override.CellMultiLine = DefaultableBoolean.True;
            e.Layout.Override.RowSizingAutoMaxLines = 5;
            e.Layout.Override.RowAlternateAppearance.BackColor = Color.LightGray;

        }

        private void printPreviewBtn_Click(object sender, EventArgs e)
        {
            
            UltraPrintPreviewDialog ultraPrintPreviewDialog1 = new UltraPrintPreviewDialog();
            ultraPrintPreviewDialog1.Document = _gridPrintDocument;

            ultraPrintPreviewDialog1.FindForm().Focus();
            ultraPrintPreviewDialog1.FindForm().WindowState = FormWindowState.Maximized;

            ultraPrintPreviewDialog1.ShowDialog();
        }

        private void ultraGrid1_InitializePrint(object sender, CancelablePrintEventArgs e)
        {
            e.PrintLayout.Override.ResetRowSizingAutoMaxLines();

            //Fit width to pages
            e.DefaultLogicalPageLayoutInfo.FitWidthToPages = 1;

            // Set up the header, 
            e.DefaultLogicalPageLayoutInfo.PageHeaderHeight = 20;
            e.DefaultLogicalPageLayoutInfo.PageHeaderBorderStyle = UIElementBorderStyle.None;

            // Set the ClippingOverride to Yes.
            e.DefaultLogicalPageLayoutInfo.ClippingOverride = ClippingOverride.Yes;

            
            e.PrintDocument.DocumentName = "My Report";
        }

        private void InitializeGridPrintDocument()
        {
            _gridPrintDocument = new UltraGridPrintDocument();
            _gridPrintDocument.Grid = this.ultraGrid1;

            // Initialize the text that will appear in the footer.
            // this can be replaceable tokens that will insert the
            // time, page number, etc.
            string textLeft = "Requested by me";
            string textRight = DateTime.Today.ToString();

            _gridPrintDocument.Footer.TextLeft = textLeft;
            _gridPrintDocument.Footer.TextRight = textRight;
            _gridPrintDocument.Footer.BorderStyle = UIElementBorderStyle.Solid;
            _gridPrintDocument.Footer.Appearance.BackColor = Color.LightGray;
            _gridPrintDocument.Footer.Margins.Top = 5;
            _gridPrintDocument.Footer.Margins.Bottom = 5;

        }
    }
}
